@@ -29,7 +29,7 @@ const examplePlugin: IPlugin<Application<Widget>, void> = {
   requires: [IJupyterWidgetRegistry],
   activate: activateWidgetExtension,
   autoStart: true
-};
+} as unknown as IPlugin<Application<Widget>, void>;
 
 export default examplePlugin;
 
